@@ -20,7 +20,7 @@ sub subsystems {
         CBLAS        FFT          Min           IEEEUtils
         CDF          Fit          QRNG
         Chebyshev    Monte        RNG           Vector
-        Heapsort     Multifit     Randist       Roots
+        Heapsort     Randist      Roots
         Combination  Histogram    Multimin      Wavelet
         Complex      Histogram2D  Multiroots    Wavelet2D
         Const        Siman        Sum           Sys
@@ -124,7 +124,23 @@ sub process_versioned_swig_files {
         close($fh) or die "Could not close $renames_fname: $!";
 
         foreach my $file (@$files_ref) {
-            $self->process_swig($file->[0], $file->[1], $ver);
+            my ($major,$minor,$tiny) = split /\./, $ver;
+            # don't create lots of XS for subsystems that didn't exist
+            # in old GSL versions
+            if ($file->[0] =~ m/Multilarge/) {
+                if ($major >=2 && $minor >= 1) {
+                    $self->process_swig($file->[0], $file->[1], $ver);
+                }
+            } else {
+                $self->process_swig($file->[0], $file->[1], $ver);
+            }
+            if ($file->[0] =~ m/Multifit/) {
+                if ($major >=2) {
+                    $self->process_swig($file->[0], $file->[1], $ver);
+                }
+            } else {
+                $self->process_swig($file->[0], $file->[1], $ver);
+            }
         }
     }
 }
@@ -204,6 +220,8 @@ sub compile_swig {
     my ($self, $file, $c_file, $ver) = @_;
     my ($cf, $p) = ($self->{config}, $self->{properties}); # For convenience
 
+    print "Creating $c_file\n";
+
     # File name, minus the suffix
     (my $file_base = $file) =~ s/\.[^.]+$//;
 
@@ -238,7 +256,7 @@ sub compile_swig {
       my $contents = <$in>;
       close $in;
 
-      $contents =~ s{("GSL_VERSION", TRUE \| 0x2 \| GV_ADDMULTI\);[\s\n]*sv_setsv\(sv, SWIG_FromCharPtr\(")\d\.\d+}
+      $contents =~ s{("GSL_VERSION", TRUE \| 0x2 \| GV_ADDMULTI\);[\s\n]*sv_setsv\(sv, SWIG_FromCharPtr\(")\d\.\d+(\.\d)?}
                     {$1$ver};
 
       open my $out, ">", $c_file or die "Can't overwrite file $c_file: $!";
